@@ -285,7 +285,7 @@ class YAMLConfig(ConfigFile):
             self.yaml.dump(data, f)
 
     def load_from_string(self, string):
-        self.yaml.load(string)
+        return self.yaml.load(string)
 
 class TOMLConfig(ConfigFile):
 
