@@ -51,6 +51,7 @@ scripts_dir = os.path.join(buildtools_dir, 'scripts')
 
 REG_EXCESSIVE_WHITESPACE = re.compile(r'\s{2,}')
 PLATFORM = platform.system()
+PATH_7ZA: typing.Optional[os.PathLike] = None
 
 def clock():
     if sys.platform == 'win32':
@@ -629,20 +630,20 @@ def _args2str(cmdlist):
     #return ' '.join([_autoescape(x) for x in cmdlist])
     return ' '.join([shlex.quote(x) for x in cmdlist])
 
-PATH_7ZA: typing.Optional[str] = None
-def decompressFile(archive, to='.', env=None):
+def decompressFile(archive: os.PathLike, to: os.PathLike='.', env=None, path7za: os.PathLike = '7za'):
     '''
     Decompresses the file to the current working directory.
 
     Uses 7za for .7z and .rar files. (p7zip)
     '''
+    
+    archive = str(archive)
+    to = str(to)
+    path7za = str(path7za)
+
     if env is None:
         env = ENV
     #print('Trying to decompress ' + archive)
-    def get7ZA():
-        if PATH_7ZA is None:
-            PATH_7ZA = env.which('7za')
-        return PATH_7ZA
     lc = archive.lower()
     if lc.endswith('.tar.gz') or lc.endswith('.tgz'):
         with tarfile.open(archive, mode='r:gz') as arch:
@@ -657,7 +658,7 @@ def decompressFile(archive, to='.', env=None):
             arch.extractall(to)
         return True
     elif lc.endswith('.tar.7z'):
-        cmd([get7ZA(), 'x', '-aoa', archive, '-o', to], echo=True, show_output=False, critical=True)
+        cmd([path7za, 'x', '-aoa', '-o'+to, '--', archive], echo=True, show_output=False, critical=True)
         with tarfile.open(archive[:-3], mode='r') as arch:
             arch.extractall(to)
         os.remove(archive[:-3])
@@ -668,13 +669,13 @@ def decompressFile(archive, to='.', env=None):
     elif lc.endswith('.7z'):
         if PLATFORM == 'Windows':
             archive = cygpath(archive)
-        cmd([get7ZA(), 'x', '-aoa', archive, '-o', to], echo=True, show_output=False, critical=True)
+        cmd([path7za, 'x', '-aoa', '-o'+to, '--', archive], echo=True, show_output=False, critical=True)
     elif lc.endswith('.zip'):
         with zipfile.ZipFile(archive) as arch:
             arch.extractall(to)
         return True
     elif lc.endswith('.rar'):
-        cmd([get7ZA(), 'x', '-aoa', archive, '-o', to], echo=True, show_output=False, critical=True)
+        cmd([path7za, 'x', '-aoa', '-o'+to, '--', archive], echo=True, show_output=False, critical=True)
     else:
         log.critical('decompressFile(): Unknown file extension: %s', archive)
     return False
